@@ -5,7 +5,8 @@ import sys
 
 import attr
 
-from rasterio.compat import urlparse
+from rasterio.compat import pathlib, string_types, urlparse
+from rasterio.errors import PathError
 
 # Supported URI schemes and their mapping to GDAL's VSI suffix.
 # TODO: extend for other cloud plaforms.
@@ -31,6 +32,9 @@ REMOTESCHEMES = set([k for k, v in SCHEMES.items() if v in ('curl', 's3', 'oss',
 class Path(object):
     """Base class for dataset paths"""
 
+    def as_vsi(self):
+        return vsi_path(self)
+
 
 @attr.s(slots=True)
 class ParsedPath(Path):
@@ -121,26 +125,40 @@ def parse_path(path):
     -----
     When legacy GDAL filenames are encountered, they will be returned
     in a UnparsedPath.
+
     """
-    # Windows drive letters (e.g. "C:\") confuse `urlparse` as they look like
-    # URL schemes
-    if sys.platform == "win32" and re.match("^[a-zA-Z]\\:", path):
-        return UnparsedPath(path)
+    if isinstance(path, Path):
+        return path
 
-    elif path.startswith('/vsi'):
-        return UnparsedPath(path)
+    elif pathlib and isinstance(path, pathlib.PurePath):
+        return ParsedPath(path.as_posix(), None, None)
 
-    else:
-        parts = urlparse(path)
+    elif isinstance(path, string_types):
 
-        # if the scheme is not one of Rasterio's supported schemes, we
-        # return an UnparsedPath.
-        if parts.scheme and not all(p in SCHEMES for p in parts.scheme.split('+')):
+        if sys.platform == "win32" and re.match(r"^[a-zA-Z]\:", path):
+            if pathlib:
+                return ParsedPath(pathlib.Path(path).as_posix(), None, None)
+            else:
+                return UnparsedPath(path)
+
+        elif path.startswith('/vsi'):
             return UnparsedPath(path)
 
         else:
+            parts = urlparse(path)
+
+    else:
+        raise PathError("invalid path '{!r}'".format(path))
+
+    # if the scheme is not one of Rasterio's supported schemes, we
+    # return an UnparsedPath.
+    if parts.scheme:
+
+        if all(p in SCHEMES for p in parts.scheme.split('+')):
             return ParsedPath.from_uri(path)
 
+    return UnparsedPath(path)
+
 
 def vsi_path(path):
     """Convert a parsed path to a GDAL VSI path
@@ -153,6 +171,7 @@ def vsi_path(path):
     Returns
     -------
     str
+
     """
     if isinstance(path, UnparsedPath):
         return path.path
